summaryrefslogtreecommitdiff
path: root/forms/source
diff options
context:
space:
mode:
authorFrank Schönheit <fs@openoffice.org>2000-10-19 10:52:20 +0000
committerFrank Schönheit <fs@openoffice.org>2000-10-19 10:52:20 +0000
commitcdbcbba7680c87249327761a04e8cfb344a2bc35 (patch)
tree97bebdb39e466b2ed1dd3c04c2259888becd6a4b /forms/source
parent6801d3a45d355ae79c1e4390eab93179986bfe69 (diff)
migrated from unotools to comphelper
Diffstat (limited to 'forms/source')
-rw-r--r--forms/source/component/Button.hxx6
-rw-r--r--forms/source/component/CheckBox.hxx10
-rw-r--r--forms/source/component/Columns.cxx16
-rw-r--r--forms/source/component/Columns.hxx18
-rw-r--r--forms/source/component/ComboBox.cxx29
-rw-r--r--forms/source/component/ComboBox.hxx8
-rw-r--r--forms/source/component/Currency.hxx6
-rw-r--r--forms/source/component/DatabaseForm.cxx45
-rw-r--r--forms/source/component/DatabaseForm.hxx28
-rw-r--r--forms/source/component/Date.cxx19
-rw-r--r--forms/source/component/Date.hxx6
-rw-r--r--forms/source/component/Edit.cxx33
-rw-r--r--forms/source/component/Edit.hxx8
-rw-r--r--forms/source/component/EventThread.hxx18
-rw-r--r--forms/source/component/File.cxx8
-rw-r--r--forms/source/component/File.hxx6
-rw-r--r--forms/source/component/FixedText.hxx6
-rw-r--r--forms/source/component/FormComponent.cxx14
-rw-r--r--forms/source/component/FormattedField.cxx46
-rw-r--r--forms/source/component/FormattedField.hxx12
-rw-r--r--forms/source/component/FormattedFieldWrapper.cxx10
-rw-r--r--forms/source/component/FormsCollection.cxx8
-rw-r--r--forms/source/component/FormsCollection.hxx14
-rw-r--r--forms/source/component/Grid.cxx8
-rw-r--r--forms/source/component/Grid.hxx8
-rw-r--r--forms/source/component/GroupBox.hxx6
-rw-r--r--forms/source/component/GroupManager.cxx12
-rw-r--r--forms/source/component/GroupManager.hxx18
-rw-r--r--forms/source/component/Hidden.hxx6
-rw-r--r--forms/source/component/ImageButton.hxx6
-rw-r--r--forms/source/component/ImageControl.cxx6
-rw-r--r--forms/source/component/ImageControl.hxx14
-rw-r--r--forms/source/component/ListBox.cxx33
-rw-r--r--forms/source/component/ListBox.hxx6
-rw-r--r--forms/source/component/Numeric.hxx6
-rw-r--r--forms/source/component/Pattern.hxx6
-rw-r--r--forms/source/component/RadioButton.hxx10
-rw-r--r--forms/source/component/Time.cxx19
-rw-r--r--forms/source/component/Time.hxx6
-rw-r--r--forms/source/inc/InterfaceContainer.hxx26
-rw-r--r--forms/source/inc/property.hxx22
-rw-r--r--forms/source/misc/InterfaceContainer.cxx40
42 files changed, 320 insertions, 312 deletions
diff --git a/forms/source/component/Button.hxx b/forms/source/component/Button.hxx
index 056d06bbd932..bf89b0d17dfb 100644
--- a/forms/source/component/Button.hxx
+++ b/forms/source/component/Button.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Button.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:04 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -95,7 +95,7 @@ namespace frm
//==================================================================
class OButtonModel
:public OImageModel
- ,public ::utl::OAggregationArrayUsageHelper<OButtonModel>
+ ,public ::comphelper::OAggregationArrayUsageHelper<OButtonModel>
{
public:
OButtonModel(const staruno::Reference<starlang::XMultiServiceFactory>& _rxFactory);
diff --git a/forms/source/component/CheckBox.hxx b/forms/source/component/CheckBox.hxx
index 17c21aa4c83e..a4a37f8089c0 100644
--- a/forms/source/component/CheckBox.hxx
+++ b/forms/source/component/CheckBox.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: CheckBox.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:04 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -66,8 +66,8 @@
#include "FormComponent.hxx"
#endif
-#ifndef _UNOTOOLS_PROPERTY_MULTIPLEX_HXX_
-#include <unotools/propmultiplex.hxx>
+#ifndef _COMPHELPER_PROPERTY_MULTIPLEX_HXX_
+#include <comphelper/propmultiplex.hxx>
#endif
//.........................................................................
@@ -81,7 +81,7 @@ enum { CB_NOCHECK, CB_CHECK, CB_DONTKNOW };
//==================================================================
class OCheckBoxModel :public OBoundControlModel
,public OPropertyChangeListener
- ,public ::utl::OAggregationArrayUsageHelper< OCheckBoxModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OCheckBoxModel >
{
::rtl::OUString m_sReferenceValue; // Referenzwert zum Checken des Buttons
sal_Int16 m_nDefaultChecked; // Soll beim Reset gecheckt werden ?
diff --git a/forms/source/component/Columns.cxx b/forms/source/component/Columns.cxx
index e6c053033753..24e29958a53a 100644
--- a/forms/source/component/Columns.cxx
+++ b/forms/source/component/Columns.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Columns.cxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: fs $ $Date: 2000-09-19 14:41:51 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -90,14 +90,14 @@
#ifndef _COM_SUN_STAR_LANG_XSERVICEINFO_HPP_
#include <com/sun/star/lang/XServiceInfo.hpp>
#endif
-#ifndef _UTL_SEQUENCE_HXX_
-#include <unotools/sequence.hxx>
+#ifndef _COMPHELPER_SEQUENCE_HXX_
+#include <comphelper/sequence.hxx>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UTL_BASIC_IO_HXX_
-#include <unotools/basicio.hxx>
+#ifndef _COMPHELPER_BASIC_IO_HXX_
+#include <comphelper/basicio.hxx>
#endif
#ifndef _FRM_SERVICES_HXX_
diff --git a/forms/source/component/Columns.hxx b/forms/source/component/Columns.hxx
index 954d77b9aad1..2356c94dad43 100644
--- a/forms/source/component/Columns.hxx
+++ b/forms/source/component/Columns.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Columns.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:04 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -65,14 +65,14 @@
#ifndef _CPPUHELPER_COMPONENT_HXX_
#include <cppuhelper/component.hxx>
#endif
-#ifndef _UNOTOOLS_PROPERTY_ARRAY_HELPER_HXX_
-#include <unotools/proparrhlp.hxx>
+#ifndef _COMPHELPER_PROPERTY_ARRAY_HELPER_HXX_
+#include <comphelper/proparrhlp.hxx>
#endif
-#ifndef _UNOTOOLS_PROPERTY_AGGREGATION_HXX_
-#include <unotools/propagg.hxx>
+#ifndef _COMPHELPER_PROPERTY_AGGREGATION_HXX_
+#include <comphelper/propagg.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
#include "strings.hxx"
@@ -89,7 +89,7 @@
#include <com/sun/star/lang/XUnoTunnel.hpp>
#endif
-using namespace utl;
+using namespace comphelper;
//.........................................................................
namespace frm
diff --git a/forms/source/component/ComboBox.cxx b/forms/source/component/ComboBox.cxx
index 3e18ce861db3..8d31b275dfcd 100644
--- a/forms/source/component/ComboBox.cxx
+++ b/forms/source/component/ComboBox.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ComboBox.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:04 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -86,17 +86,17 @@
#ifndef _FORMS_BASELISTBOX_HXX_
#include "BaseListBox.hxx"
#endif
-#ifndef _UTL_NUMBERS_HXX_
-#include <unotools/numbers.hxx>
+#ifndef _COMPHELPER_NUMBERS_HXX_
+#include <comphelper/numbers.hxx>
#endif
-#ifndef _UNOTOOLS_DATETIME_HXX_
-#include <unotools/datetime.hxx>
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
-#ifndef _UTL_DB_CONVERSION_HXX_
-#include <unotools/dbconversion.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
#ifndef _COM_SUN_STAR_SDB_SQLERROREVENT_HPP_
@@ -124,6 +124,8 @@
#include <com/sun/star/awt/XListBox.hpp>
#endif
+using namespace dbtools;
+
//.........................................................................
namespace frm
{
@@ -190,7 +192,7 @@ OComboBoxModel::OComboBoxModel(const staruno::Reference<starlang::XMultiServiceF
// use the old control name for compytibility reasons
,m_eListSourceType(starform::ListSourceType_TABLE)
,m_bEmptyIsNull(sal_True)
- ,m_aNullDate(STANDARD_DB_DATE)
+ ,m_aNullDate(DBTypeConversion::STANDARD_DB_DATE)
,m_nKeyType(starutil::NumberFormat::UNDEFINED)
,m_nFormatKey(0)
,m_nFieldType(starsdbc::DataType::OTHER)
@@ -717,8 +719,7 @@ void OComboBoxModel::_loaded(const starlang::EventObject& rEvent)
m_xFormatter->attachNumberFormatsSupplier(xSupplier);
m_nKeyType = getNumberFormatType(xSupplier->getNumberFormats(), m_nFormatKey);
- typeConvert(*(starutil::Date*)xSupplier->getNumberFormatSettings()->getPropertyValue(::rtl::OUString::createFromAscii("NullDate")).getValue(),
- m_aNullDate);
+ xSupplier->getNumberFormatSettings()->getPropertyValue(::rtl::OUString::createFromAscii("NullDate")) >>= m_aNullDate;
}
}
@@ -736,7 +737,7 @@ void OComboBoxModel::_unloaded()
m_nFieldType = starsdbc::DataType::OTHER;
m_nFormatKey = 0;
m_nKeyType = starutil::NumberFormat::UNDEFINED;
- m_aNullDate = STANDARD_DB_DATE;
+ m_aNullDate = DBTypeConversion::STANDARD_DB_DATE;
}
// Zuruecksetzen der Inhalte (s.o)
diff --git a/forms/source/component/ComboBox.hxx b/forms/source/component/ComboBox.hxx
index c313b2eeec14..2901d7130460 100644
--- a/forms/source/component/ComboBox.hxx
+++ b/forms/source/component/ComboBox.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ComboBox.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:04 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -93,7 +93,7 @@ namespace frm
class OComboBoxModel
:public OBoundControlModel
,public starsdb::XSQLErrorBroadcaster
- ,public ::utl::OAggregationArrayUsageHelper< OComboBoxModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OComboBoxModel >
{
staruno::Reference<starutil::XNumberFormatter> m_xFormatter;
starform::ListSourceType m_eListSourceType; // type der list source
@@ -102,7 +102,7 @@ class OComboBoxModel
::rtl::OUString m_aDefaultText; // DefaultText
::rtl::OUString m_aSaveValue;
sal_Int32 m_nFormatKey;
- Date m_aNullDate;
+ starutil::Date m_aNullDate;
sal_Int32 m_nFieldType;
sal_Int16 m_nKeyType;
sal_Bool m_bEmptyIsNull; // LeerString wird als NULL interpretiert
diff --git a/forms/source/component/Currency.hxx b/forms/source/component/Currency.hxx
index 6ebab3bddb20..263db2f8e17e 100644
--- a/forms/source/component/Currency.hxx
+++ b/forms/source/component/Currency.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Currency.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:04 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -76,7 +76,7 @@ namespace frm
//==================================================================
class OCurrencyModel
:public OEditBaseModel
- ,public ::utl::OAggregationArrayUsageHelper< OCurrencyModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OCurrencyModel >
{
staruno::Any m_aSaveValue;
diff --git a/forms/source/component/DatabaseForm.cxx b/forms/source/component/DatabaseForm.cxx
index cb4222a191fd..3cd2fbf5ddb2 100644
--- a/forms/source/component/DatabaseForm.cxx
+++ b/forms/source/component/DatabaseForm.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: DatabaseForm.cxx,v $
*
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
- * last change: $Author: fs $ $Date: 2000-10-19 10:41:31 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -187,26 +187,26 @@
#ifndef _CPPUHELPER_IMPLBASE2_HXX_
#include <cppuhelper/implbase2.hxx>
#endif
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-#ifndef _UTL_SEQUENCE_HXX_
-#include <unotools/sequence.hxx>
+#ifndef _COMPHELPER_SEQUENCE_HXX_
+#include <comphelper/sequence.hxx>
#endif
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
-#ifndef _UNOTOOLS_ENUMHELPER_HXX_
-#include <unotools/enumhelper.hxx>
+#ifndef _COMPHELPER_ENUMHELPER_HXX_
+#include <comphelper/enumhelper.hxx>
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include <unotools/container.hxx>
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
#ifndef _OSL_MUTEX_HXX_
#include <osl/mutex.hxx>
@@ -217,15 +217,6 @@
#ifndef _TOOLS_SOLMATH_HXX
#include <tools/solmath.hxx>
#endif
-#ifndef _DATE_HXX
-#include <tools/Date.hxx>
-#endif
-#ifndef _TOOLS_TIME_HXX
-#include <tools/Time.hxx>
-#endif
-#ifndef _DATETIME_HXX
-#include <tools/DateTime.hxx>
-#endif
#ifndef _INETTYPE_HXX
#include <svtools/inettype.hxx>
#endif
@@ -244,6 +235,8 @@
#define DATABASEFORM_IMPLEMENTATION_NAME ::rtl::OUString::createFromAscii("com.sun.star.form.component.ODatabaseForm")
+using namespace dbtools;
+
//.........................................................................
namespace frm
{
@@ -282,7 +275,7 @@ staruno::Reference< starframe::XModel> getXModel(const staruno::Reference< staru
class OParameterWrapper
:public ::cppu::OWeakObject
,public ::cppu::OPropertySetHelper
- ,public ::utl::OAggregationArrayUsageHelper<OParameterWrapper>
+ ,public ::comphelper::OAggregationArrayUsageHelper<OParameterWrapper>
{
staruno::Any m_aValue;
::osl::Mutex m_aMutex;
diff --git a/forms/source/component/DatabaseForm.hxx b/forms/source/component/DatabaseForm.hxx
index 6d6549e17aed..db6fe34fbcd7 100644
--- a/forms/source/component/DatabaseForm.hxx
+++ b/forms/source/component/DatabaseForm.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: DatabaseForm.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -152,20 +152,20 @@
#include "ids.hxx"
#endif
-#ifndef _UNOTOOLS_PROPERTY_AGGREGATION_HXX_
-#include <unotools/propagg.hxx>
+#ifndef _COMPHELPER_PROPERTY_AGGREGATION_HXX_
+#include <comphelper/propagg.hxx>
#endif
-#ifndef _UNOTOOLS_PROPERTY_MULTIPLEX_HXX_
-#include <unotools/propmultiplex.hxx>
+#ifndef _COMPHELPER_PROPERTY_MULTIPLEX_HXX_
+#include <comphelper/propmultiplex.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
-#ifndef _UNOTOOLS_GUARDING_HXX_
-#include <unotools/guarding.hxx>
+#ifndef _COMPHELPER_GUARDING_HXX_
+#include <comphelper/guarding.hxx>
#endif
-#ifndef _UNOTOOLS_PROPERTY_ARRAY_HELPER_HXX_
-#include <unotools/proparrhlp.hxx>
+#ifndef _COMPHELPER_PROPERTY_ARRAY_HELPER_HXX_
+#include <comphelper/proparrhlp.hxx>
#endif
namespace com { namespace sun { namespace star { namespace sdbc {
@@ -175,7 +175,7 @@ namespace com { namespace sun { namespace star { namespace sdbc {
class Timer;
class INetMIMEMessage;
-typedef ::utl::OReusableGuard< ::osl::Mutex > ReusableMutexGuard;
+typedef ::comphelper::OReusableGuard< ::osl::Mutex > ReusableMutexGuard;
//.........................................................................
namespace frm
@@ -228,7 +228,7 @@ struct OParameterInfoImpl;
class ODatabaseForm :public OFormComponents
,public OPropertySetAggregationHelper
,public OPropertyChangeListener
- ,public ::utl::OAggregationArrayUsageHelper<ODatabaseForm>
+ ,public ::comphelper::OAggregationArrayUsageHelper<ODatabaseForm>
,public starsdb::XSQLErrorBroadcaster
// service com::sun::star::form::component::Form (supported by com::sun::star::form::component::DataForm)
,public starform::XForm
diff --git a/forms/source/component/Date.cxx b/forms/source/component/Date.cxx
index a19f51a7c918..1585b5170da7 100644
--- a/forms/source/component/Date.cxx
+++ b/forms/source/component/Date.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Date.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -69,17 +69,19 @@
#ifndef _DATE_HXX
#include <tools/date.hxx>
#endif
-#ifndef _UNOTOOLS_DATETIME_HXX_
-#include <unotools/datetime.hxx>
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
#endif
-#ifndef _UTL_DB_CONVERSION_HXX_
-#include <unotools/dbconversion.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
#ifndef _COM_SUN_STAR_SDBC_DATATYPE_HPP_
#include <com/sun/star/sdbc/DataType.hpp>
#endif
+using namespace dbtools;
+
//.........................................................................
namespace frm
{
@@ -232,8 +234,7 @@ sal_Bool ODateModel::_commit()
{
sal_Int32 nAsInt(0);
aNewValue >>= nAsInt;
- Date aToolsValue(nAsInt);
- typeConvert(aToolsValue, aDate);
+ aDate = DBTypeConversion::toDate(nAsInt);
}
if (!m_bDateTimeField)
@@ -285,7 +286,7 @@ void ODateModel::_reset()
else
{ // aktuelles Datum einstellen
Date aCurrentDate;
- aValue <<= DBTypeConversion::toINT32(aCurrentDate);
+ aValue <<= (sal_Int32)aCurrentDate.GetDate();
}
{ // release our mutex once (it's acquired in the calling method !), as setting aggregate properties
diff --git a/forms/source/component/Date.hxx b/forms/source/component/Date.hxx
index b7d7013f3a50..65b079e077f3 100644
--- a/forms/source/component/Date.hxx
+++ b/forms/source/component/Date.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Date.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -76,7 +76,7 @@ namespace frm
//==================================================================
class ODateModel
:public OEditBaseModel
- ,public ::utl::OAggregationArrayUsageHelper< ODateModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< ODateModel >
{
staruno::Any m_aSaveValue;
sal_Bool m_bDateTimeField;
diff --git a/forms/source/component/Edit.cxx b/forms/source/component/Edit.cxx
index 64dd23a18b57..5427533318c8 100644
--- a/forms/source/component/Edit.cxx
+++ b/forms/source/component/Edit.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Edit.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -93,19 +93,25 @@
#include <tools/vclrsc.hxx>
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include <unotools/container.hxx>
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
+#endif
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
+#endif
+#ifndef _COMPHELPER_NUMBERS_HXX_
+#include <comphelper/numbers.hxx>
#endif
-#include <unotools/datetime.hxx>
-#include <unotools/numbers.hxx>
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
-#ifndef _UTL_DB_CONVERSION_HXX_
-#include <unotools/dbconversion.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
+using namespace dbtools;
+
//.........................................................................
namespace frm
{
@@ -354,7 +360,7 @@ OEditModel::OEditModel(const staruno::Reference<starlang::XMultiServiceFactory>&
:OEditBaseModel( _rxFactory, VCL_CONTROLMODEL_EDIT, FRM_CONTROL_EDIT )
// use the old control name for compytibility reasons
,m_nMaxLen(0)
- ,m_aNullDate(STANDARD_DB_DATE)
+ ,m_aNullDate(DBTypeConversion::STANDARD_DB_DATE)
,m_nKeyType(starutil::NumberFormat::UNDEFINED)
,m_nFormatKey(0)
,m_nFieldType(starsdbc::DataType::OTHER)
@@ -529,7 +535,8 @@ void OEditModel::_loaded(const starlang::EventObject& rEvent)
m_xFormatter->attachNumberFormatsSupplier(xSupplier);
m_nKeyType = getNumberFormatType(xSupplier->getNumberFormats(), m_nFormatKey);
- typeConvert(*(starutil::Date*)xSupplier->getNumberFormatSettings()->getPropertyValue(::rtl::OUString::createFromAscii("NullDate")).getValue(), m_aNullDate);
+ xSupplier->getNumberFormatSettings()->getPropertyValue(::rtl::OUString::createFromAscii("NullDate"))
+ >>= m_aNullDate;
}
if (m_nKeyType != starutil::NumberFormat::SCIENTIFIC)
@@ -573,7 +580,7 @@ void OEditModel::_unloaded()
m_nFieldType = starsdbc::DataType::OTHER;
m_nFormatKey = 0;
m_nKeyType = starutil::NumberFormat::UNDEFINED;
- m_aNullDate = STANDARD_DB_DATE;
+ m_aNullDate = DBTypeConversion::STANDARD_DB_DATE;
}
}
diff --git a/forms/source/component/Edit.hxx b/forms/source/component/Edit.hxx
index b07932e210ad..8c8e5bb9949a 100644
--- a/forms/source/component/Edit.hxx
+++ b/forms/source/component/Edit.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Edit.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -75,12 +75,12 @@ namespace frm
//==================================================================
class OEditModel
:public OEditBaseModel
- ,public ::utl::OAggregationArrayUsageHelper< OEditModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OEditModel >
{
staruno::Reference<starutil::XNumberFormatter> m_xFormatter;
::rtl::OUString m_aSaveValue;
sal_Int32 m_nFormatKey;
- Date m_aNullDate;
+ starutil::Date m_aNullDate;
sal_Int32 m_nFieldType;
sal_Int16 m_nKeyType;
sal_Int16 m_nMaxLen;
diff --git a/forms/source/component/EventThread.hxx b/forms/source/component/EventThread.hxx
index 5bf63e85c539..deaae8911e1d 100644
--- a/forms/source/component/EventThread.hxx
+++ b/forms/source/component/EventThread.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: EventThread.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -76,16 +76,16 @@
#include <cppuhelper/component.hxx>
#endif
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-#ifndef _UNOTOOLS_GUARDING_HXX_
-#include <unotools/guarding.hxx>
+#ifndef _COMPHELPER_GUARDING_HXX_
+#include <comphelper/guarding.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
-using namespace utl;
+using namespace comphelper;
//.........................................................................
namespace frm
diff --git a/forms/source/component/File.cxx b/forms/source/component/File.cxx
index 13623179f644..691f8e58126d 100644
--- a/forms/source/component/File.cxx
+++ b/forms/source/component/File.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: File.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -76,8 +76,8 @@
#ifndef _TOOLS_DEBUG_HXX
#include <tools/debug.hxx>
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include <unotools/container.hxx>
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
#endif
//.........................................................................
diff --git a/forms/source/component/File.hxx b/forms/source/component/File.hxx
index dccaafaf01c0..8539a4389dbb 100644
--- a/forms/source/component/File.hxx
+++ b/forms/source/component/File.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: File.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -77,7 +77,7 @@ namespace frm
class OFileControlModel
:public OControlModel
,public starform::XReset
- ,public ::utl::OAggregationArrayUsageHelper< OFileControlModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OFileControlModel >
{
::cppu::OInterfaceContainerHelper m_aResetListeners;
::rtl::OUString m_sDefaultValue;
diff --git a/forms/source/component/FixedText.hxx b/forms/source/component/FixedText.hxx
index aafd01923750..e224843ae458 100644
--- a/forms/source/component/FixedText.hxx
+++ b/forms/source/component/FixedText.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: FixedText.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -75,7 +75,7 @@ namespace frm
//==================================================================
class OFixedTextModel
:public OControlModel
- ,public ::utl::OAggregationArrayUsageHelper< OFixedTextModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OFixedTextModel >
{
protected:
// UNO Anbindung
diff --git a/forms/source/component/FormComponent.cxx b/forms/source/component/FormComponent.cxx
index 371d3507a86d..15c5c9fcedc6 100644
--- a/forms/source/component/FormComponent.cxx
+++ b/forms/source/component/FormComponent.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: FormComponent.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -93,11 +93,11 @@
#include <com/sun/star/sdbc/ColumnValue.hpp>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
#ifndef _FRM_PROPERTY_HRC_
#include "property.hrc"
@@ -106,6 +106,8 @@
#include "services.hxx"
#endif
+using namespace dbtools;
+
//... namespace frm .......................................................
namespace frm
{
diff --git a/forms/source/component/FormattedField.cxx b/forms/source/component/FormattedField.cxx
index dc3b1773714f..9bfac82c43be 100644
--- a/forms/source/component/FormattedField.cxx
+++ b/forms/source/component/FormattedField.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: FormattedField.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -72,20 +72,20 @@
#include "property.hxx"
#endif
-#ifndef _UTL_SEQUENCE_HXX_
-#include <unotools/sequence.hxx>
+#ifndef _COMPHELPER_SEQUENCE_HXX_
+#include <comphelper/sequence.hxx>
#endif
-#ifndef _UTL_NUMBERS_HXX_
-#include <unotools/numbers.hxx>
+#ifndef _COMPHELPER_NUMBERS_HXX_
+#include <comphelper/numbers.hxx>
#endif
-#ifndef _UNOTOOLS_DATETIME_HXX_
-#include <unotools/datetime.hxx>
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
-#ifndef _UTL_DB_CONVERSION_HXX_
-#include <unotools/dbconversion.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
#ifndef _ZFORLIST_HXX //autogen
@@ -157,6 +157,8 @@
#endif
#endif
+using namespace dbtools;
+
/** implements handling for compatibly reading/writing data from/into an input/output stream.
data written in a block secured by this class should be readable by older versions which
use the same mechanism.
@@ -478,7 +480,7 @@ OFormattedModel::OFormattedModel(const staruno::Reference<starlang::XMultiServic
,m_bOriginalNumeric(sal_False)
,m_bNumeric(sal_False)
,m_xOriginalFormatter(NULL)
- ,m_aNullDate(STANDARD_DB_DATE)
+ ,m_aNullDate(DBTypeConversion::STANDARD_DB_DATE)
,m_nKeyType(starutil::NumberFormat::UNDEFINED)
{
m_nClassId = starform::FormComponentType::TEXTFIELD;
@@ -841,8 +843,8 @@ void OFormattedModel::_loaded(const starlang::EventObject& rEvent)
setPropertyValue(PROPERTY_TREATASNUMERIC, staruno::makeAny((sal_Bool)m_bNumeric));
m_nKeyType = getNumberFormatType(xSupplier->getNumberFormats(), getINT32(aFmtKey));
- typeConvert(*(starutil::Date*)xSupplier->getNumberFormatSettings()->getPropertyValue(s_aNullDataProp).getValue(),
- m_aNullDate);
+ xSupplier->getNumberFormatSettings()->getPropertyValue(s_aNullDataProp)
+ >>= m_aNullDate;
}
}
else
@@ -851,8 +853,8 @@ void OFormattedModel::_loaded(const starlang::EventObject& rEvent)
m_bNumeric = getBOOL(getPropertyValue(PROPERTY_TREATASNUMERIC));
m_nKeyType = getNumberFormatType(xSupplier->getNumberFormats(), getINT32(aFmtKey));
- typeConvert(*(starutil::Date*)xSupplier->getNumberFormatSettings()->getPropertyValue(s_aNullDataProp).getValue(),
- m_aNullDate);
+ xSupplier->getNumberFormatSettings()->getPropertyValue(s_aNullDataProp)
+ >>= m_aNullDate;
}
}
else
@@ -861,8 +863,8 @@ void OFormattedModel::_loaded(const starlang::EventObject& rEvent)
m_bNumeric = getBOOL(getPropertyValue(PROPERTY_TREATASNUMERIC));
m_nKeyType = getNumberFormatType(xSupplier->getNumberFormats(), 0);
- typeConvert(*(starutil::Date*)xSupplier->getNumberFormatSettings()->getPropertyValue(s_aNullDataProp).getValue(),
- m_aNullDate);
+ xSupplier->getNumberFormatSettings()->getPropertyValue(s_aNullDataProp)
+ >>= m_aNullDate;
}
OEditBaseModel::_loaded(rEvent);
@@ -881,7 +883,7 @@ void OFormattedModel::_unloaded()
}
m_nKeyType = starutil::NumberFormat::UNDEFINED;
- m_aNullDate = STANDARD_DB_DATE;
+ m_aNullDate = DBTypeConversion::STANDARD_DB_DATE;
}
//------------------------------------------------------------------------------
@@ -979,11 +981,11 @@ void OFormattedModel::write(const staruno::Reference<stario::XObjectOutputStream
{
case staruno::TypeClass_STRING:
_rxOutStream->writeShort(0x0000);
- _rxOutStream->writeUTF(::utl::getString(aEffectiveValue));
+ _rxOutStream->writeUTF(::comphelper::getString(aEffectiveValue));
break;
case staruno::TypeClass_DOUBLE:
_rxOutStream->writeShort(0x0001);
- _rxOutStream->writeDouble(::utl::getDouble(aEffectiveValue));
+ _rxOutStream->writeDouble(::comphelper::getDouble(aEffectiveValue));
break;
default: // void and all unknown states
DBG_ASSERT(!aEffectiveValue.hasValue(), "FmXFormattedModel::write : unknown property value type !");
diff --git a/forms/source/component/FormattedField.hxx b/forms/source/component/FormattedField.hxx
index d19f037d00af..c1374dd87751 100644
--- a/forms/source/component/FormattedField.hxx
+++ b/forms/source/component/FormattedField.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: FormattedField.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -70,8 +70,8 @@
#include <tools/lang.hxx>
#endif
-#ifndef _UNOTOOLS_PROPERTY_MULTIPLEX_HXX_
-#include <unotools/propmultiplex.hxx>
+#ifndef _COMPHELPER_PROPERTY_MULTIPLEX_HXX_
+#include <comphelper/propmultiplex.hxx>
#endif
//.........................................................................
@@ -84,12 +84,12 @@ namespace frm
class OFormattedModel
:public OEditBaseModel
,public OPropertyChangeListener
- ,public ::utl::OAggregationArrayUsageHelper< OFormattedModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OFormattedModel >
{
// das Original, falls ich die Format-Properties meines aggregierten Models gefaket, d.h. von dem Feld, an das
// ich gebunden bin, weitergereicht habe (nur gueltig wenn loaded)
staruno::Reference<starutil::XNumberFormatsSupplier> m_xOriginalFormatter;
- Date m_aNullDate;
+ starutil::Date m_aNullDate;
staruno::Any m_aSaveValue;
sal_Int16 m_nKeyType;
diff --git a/forms/source/component/FormattedFieldWrapper.cxx b/forms/source/component/FormattedFieldWrapper.cxx
index 0c1ce3b07817..c994f4738e8f 100644
--- a/forms/source/component/FormattedFieldWrapper.cxx
+++ b/forms/source/component/FormattedFieldWrapper.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: FormattedFieldWrapper.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -77,8 +77,8 @@
#ifndef _FRM_SERVICES_HXX_
#include "services.hxx"
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
#ifndef _ISOLANG_HXX
@@ -225,7 +225,7 @@ void SAL_CALL OFormattedFieldWrapper::write(const staruno::Reference<stario::XOb
sCountry,
::rtl::OUString());
- TransferFormComponentProperties(xFormatProps, xEditProps, aAppLanguage);
+ dbtools::TransferFormComponentProperties(xFormatProps, xEditProps, aAppLanguage);
// then write the edit part, after switching to "fake mode"
m_pEditPart->enableFormattedWriteFake();
diff --git a/forms/source/component/FormsCollection.cxx b/forms/source/component/FormsCollection.cxx
index c7b3acf4f78c..75999c5bf811 100644
--- a/forms/source/component/FormsCollection.cxx
+++ b/forms/source/component/FormsCollection.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: FormsCollection.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:04 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -65,8 +65,8 @@
#include "services.hxx"
#endif
-#ifndef _UTL_SEQUENCE_HXX_
-#include <unotools/sequence.hxx>
+#ifndef _COMPHELPER_SEQUENCE_HXX_
+#include <comphelper/sequence.hxx>
#endif
#ifndef _TOOLS_DEBUG_HXX
#include <tools/debug.hxx>
diff --git a/forms/source/component/FormsCollection.hxx b/forms/source/component/FormsCollection.hxx
index cfb82543d651..b9708b96b6f5 100644
--- a/forms/source/component/FormsCollection.hxx
+++ b/forms/source/component/FormsCollection.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: FormsCollection.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -67,8 +67,8 @@
#include <cppuhelper/component.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
#ifndef _FRM_IDS_HXX_
#include "ids.hxx"
@@ -101,7 +101,7 @@ class OFormsCollection
{
::osl::Mutex m_aMutex;
OImplementationIdsRef m_aHoldIdHelper;
- ::utl::InterfaceRef m_xParent; // Parent
+ ::comphelper::InterfaceRef m_xParent; // Parent
public:
OFormsCollection(const staruno::Reference<starlang::XMultiServiceFactory>& _rxFactory);
@@ -128,8 +128,8 @@ public:
virtual void SAL_CALL disposing();
// starcontainer::XChild
- virtual ::utl::InterfaceRef SAL_CALL getParent() throw(staruno::RuntimeException);
- virtual void SAL_CALL setParent(const ::utl::InterfaceRef& Parent) throw(starlang::NoSupportException, staruno::RuntimeException);
+ virtual ::comphelper::InterfaceRef SAL_CALL getParent() throw(staruno::RuntimeException);
+ virtual void SAL_CALL setParent(const ::comphelper::InterfaceRef& Parent) throw(starlang::NoSupportException, staruno::RuntimeException);
};
//.........................................................................
diff --git a/forms/source/component/Grid.cxx b/forms/source/component/Grid.cxx
index bf412134e93e..992bc0b2414c 100644
--- a/forms/source/component/Grid.cxx
+++ b/forms/source/component/Grid.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Grid.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -90,8 +90,8 @@
#ifndef _CPPUHELPER_EXTRACT_HXX_
#include <cppuhelper/extract.hxx>
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include <unotools/container.hxx>
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
#endif
#ifndef _SV_SVAPP_HXX
diff --git a/forms/source/component/Grid.hxx b/forms/source/component/Grid.hxx
index 9296506c1151..b90477227888 100644
--- a/forms/source/component/Grid.hxx
+++ b/forms/source/component/Grid.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Grid.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -81,8 +81,8 @@
#include "InterfaceContainer.hxx"
#endif
-#ifndef _UNOTOOLS_PROPERTY_ARRAY_HELPER_HXX_
-#include <unotools/proparrhlp.hxx>
+#ifndef _COMPHELPER_PROPERTY_ARRAY_HELPER_HXX_
+#include <comphelper/proparrhlp.hxx>
#endif
//.........................................................................
diff --git a/forms/source/component/GroupBox.hxx b/forms/source/component/GroupBox.hxx
index 62ec04576797..218151b74136 100644
--- a/forms/source/component/GroupBox.hxx
+++ b/forms/source/component/GroupBox.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: GroupBox.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -75,7 +75,7 @@ namespace frm
//==================================================================
class OGroupBoxModel
:public OControlModel
- ,public ::utl::OAggregationArrayUsageHelper< OGroupBoxModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OGroupBoxModel >
{
public:
OGroupBoxModel(const staruno::Reference<starlang::XMultiServiceFactory>& _rxFactory);
diff --git a/forms/source/component/GroupManager.cxx b/forms/source/component/GroupManager.cxx
index b656e9254148..24df89782333 100644
--- a/forms/source/component/GroupManager.cxx
+++ b/forms/source/component/GroupManager.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: GroupManager.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -68,11 +68,11 @@
#include <com/sun/star/beans/XFastPropertySet.hpp>
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UTL_TYPES_HXX_
-#include <unotools/types.hxx>
+#ifndef _COMPHELPER_TYPES_HXX_
+#include <comphelper/types.hxx>
#endif
#ifndef _SOLAR_H
diff --git a/forms/source/component/GroupManager.hxx b/forms/source/component/GroupManager.hxx
index 8ef74c7e9352..0732fe98774c 100644
--- a/forms/source/component/GroupManager.hxx
+++ b/forms/source/component/GroupManager.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: GroupManager.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -68,21 +68,21 @@
#include <com/sun/star/beans/XPropertyChangeListener.hpp>
#include <com/sun/star/container/XContainerListener.hpp>
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
#ifndef _CPPUHELPER_IMPLBASE2_HXX_
#include <cppuhelper/implbase2.hxx>
#endif
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-#ifndef _UTL_TYPES_HXX_
-#include <unotools/types.hxx>
+#ifndef _COMPHELPER_TYPES_HXX_
+#include <comphelper/types.hxx>
#endif
-using namespace utl;
+using namespace comphelper;
/*========================================================================
Funktionsweise GroupManager:
diff --git a/forms/source/component/Hidden.hxx b/forms/source/component/Hidden.hxx
index 095903e1c4ad..ba15b779cca6 100644
--- a/forms/source/component/Hidden.hxx
+++ b/forms/source/component/Hidden.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Hidden.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -75,7 +75,7 @@ namespace frm
//==================================================================
class OHiddenModel
:public OControlModel
- ,public ::utl::OAggregationArrayUsageHelper< OHiddenModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OHiddenModel >
{
::rtl::OUString m_sHiddenValue;
diff --git a/forms/source/component/ImageButton.hxx b/forms/source/component/ImageButton.hxx
index fab7633e4efe..37da51efaf6b 100644
--- a/forms/source/component/ImageButton.hxx
+++ b/forms/source/component/ImageButton.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ImageButton.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -80,7 +80,7 @@ namespace frm
//==================================================================
class OImageButtonModel
:public OImageModel
- ,public ::utl::OAggregationArrayUsageHelper< OImageButtonModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OImageButtonModel >
{
public:
OImageButtonModel(const staruno::Reference<starlang::XMultiServiceFactory>& _rxFactory);
diff --git a/forms/source/component/ImageControl.cxx b/forms/source/component/ImageControl.cxx
index eb3da3ce913a..d93b751ee52b 100644
--- a/forms/source/component/ImageControl.cxx
+++ b/forms/source/component/ImageControl.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ImageControl.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -609,7 +609,7 @@ void OImageControlControl::mousePressed(const starawt::MouseEvent& e)
{
// but only if our IMAGE_URL property is handled as if it is transient, which is equivalent to
// an empty control source
- if (!hasProperty(PROPERTY_CONTROLSOURCE, xSet) || (::utl::getString(xSet->getPropertyValue(PROPERTY_CONTROLSOURCE)).getLength() != 0))
+ if (!hasProperty(PROPERTY_CONTROLSOURCE, xSet) || (::comphelper::getString(xSet->getPropertyValue(PROPERTY_CONTROLSOURCE)).getLength() != 0))
return;
}
diff --git a/forms/source/component/ImageControl.hxx b/forms/source/component/ImageControl.hxx
index 1d4a4eae4705..9a3c30cfc5af 100644
--- a/forms/source/component/ImageControl.hxx
+++ b/forms/source/component/ImageControl.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ImageControl.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -75,10 +75,10 @@
#include <com/sun/star/awt/XMouseListener.hpp>
#endif
-#ifndef _UNOTOOLS_PROPERTY_MULTIPLEX_HXX_
-#include <unotools/propmultiplex.hxx>
+#ifndef _COMPHELPER_PROPERTY_MULTIPLEX_HXX_
+#include <comphelper/propmultiplex.hxx>
#endif
-using namespace utl;
+using namespace comphelper;
//.........................................................................
namespace frm
@@ -90,7 +90,7 @@ namespace frm
//==================================================================
class OImageControlModel
:public starform::XImageProducerSupplier
- ,public ::utl::OAggregationArrayUsageHelper<OImageControlModel>
+ ,public ::comphelper::OAggregationArrayUsageHelper<OImageControlModel>
,public OBoundControlModel
,public OPropertyChangeListener
{
@@ -150,7 +150,7 @@ public:
// starform::XImageProducerSupplier
virtual staruno::Reference<starawt::XImageProducer> SAL_CALL getImageProducer() { return m_xImageProducer; }
-// ::utl::OAggregationArrayUsageHelper
+// ::comphelper::OAggregationArrayUsageHelper
virtual void fillProperties(
staruno::Sequence< starbeans::Property >& /* [out] */ _rProps,
staruno::Sequence< starbeans::Property >& /* [out] */ _rAggregateProps
diff --git a/forms/source/component/ListBox.cxx b/forms/source/component/ListBox.cxx
index fa097dfe5261..2fd5a361aeca 100644
--- a/forms/source/component/ListBox.cxx
+++ b/forms/source/component/ListBox.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ListBox.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:05 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -86,20 +86,20 @@
#ifndef _FORMS_BASELISTBOX_HXX_
#include "BaseListBox.hxx"
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include <unotools/container.hxx>
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
#endif
-#ifndef _UNOTOOLS_DATETIME_HXX_
-#include <unotools/datetime.hxx>
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
#endif
-#ifndef _UTL_NUMBERS_HXX_
-#include <unotools/numbers.hxx>
+#ifndef _COMPHELPER_NUMBERS_HXX_
+#include <comphelper/numbers.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
-#ifndef _UTL_DB_CONVERSION_HXX_
-#include <unotools/dbconversion.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
#ifndef _COM_SUN_STAR_SDB_SQLERROREVENT_HPP_
@@ -130,6 +130,8 @@
#include <com/sun/star/awt/XWindow.hpp>
#endif
+using namespace dbtools;
+
//.........................................................................
namespace frm
{
@@ -765,7 +767,7 @@ void OListBoxModel::loadData()
return;
}
- Date aNullDate(STANDARD_DB_DATE);
+ starutil::Date aNullDate(DBTypeConversion::STANDARD_DB_DATE);
sal_Int32 nFormatKey = 0;
sal_Int32 nFieldType = starsdbc::DataType::OTHER;
sal_Int16 nKeyType = starutil::NumberFormat::UNDEFINED;
@@ -790,9 +792,8 @@ void OListBoxModel::loadData()
if (xFormatter.is())
{
xFormatter->attachNumberFormatsSupplier(xSupplier);
- typeConvert(*(starutil::Date*)xFormatter->getNumberFormatsSupplier()->getNumberFormatSettings()->getPropertyValue(
- ::rtl::OUString::createFromAscii("NullDate")).getValue(),
- aNullDate);
+ xFormatter->getNumberFormatsSupplier()->getNumberFormatSettings()->getPropertyValue(
+ ::rtl::OUString::createFromAscii("NullDate")) >>= aNullDate;
nKeyType = getNumberFormatType(xFormatter->getNumberFormatsSupplier()->getNumberFormats(), nFormatKey);
}
}
diff --git a/forms/source/component/ListBox.hxx b/forms/source/component/ListBox.hxx
index 26e3b4964c74..97ebedc8a76b 100644
--- a/forms/source/component/ListBox.hxx
+++ b/forms/source/component/ListBox.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ListBox.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -99,7 +99,7 @@ class OListBoxModel
:public OBoundControlModel
,public starsdb::XSQLErrorBroadcaster
,public starutil::XRefreshable
- ,public ::utl::OAggregationArrayUsageHelper< OListBoxModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OListBoxModel >
{
staruno::Any m_aSaveValue;
diff --git a/forms/source/component/Numeric.hxx b/forms/source/component/Numeric.hxx
index ab02748f1f93..2bf26e89767a 100644
--- a/forms/source/component/Numeric.hxx
+++ b/forms/source/component/Numeric.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Numeric.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -76,7 +76,7 @@ namespace frm
//==================================================================
class ONumericModel
:public OEditBaseModel
- ,public ::utl::OAggregationArrayUsageHelper< ONumericModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< ONumericModel >
{
staruno::Any m_aSaveValue;
static sal_Int32 nValueHandle;
diff --git a/forms/source/component/Pattern.hxx b/forms/source/component/Pattern.hxx
index 4276e2fc2fa7..59729f7c9d2f 100644
--- a/forms/source/component/Pattern.hxx
+++ b/forms/source/component/Pattern.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Pattern.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -76,7 +76,7 @@ namespace frm
//==================================================================
class OPatternModel
:public OEditBaseModel
- ,public ::utl::OAggregationArrayUsageHelper< OPatternModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OPatternModel >
{
::rtl::OUString m_aSaveValue;
diff --git a/forms/source/component/RadioButton.hxx b/forms/source/component/RadioButton.hxx
index 9df628f846e9..bd05715174b6 100644
--- a/forms/source/component/RadioButton.hxx
+++ b/forms/source/component/RadioButton.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: RadioButton.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -66,8 +66,8 @@
#include "FormComponent.hxx"
#endif
-#ifndef _UNOTOOLS_PROPERTY_MULTIPLEX_HXX_
-#include <unotools/propmultiplex.hxx>
+#ifndef _COMPHELPER_PROPERTY_MULTIPLEX_HXX_
+#include <comphelper/propmultiplex.hxx>
#endif
//.........................................................................
@@ -81,7 +81,7 @@ enum { RB_NOCHECK, RB_CHECK, RB_DONTKNOW };
//==================================================================
class ORadioButtonModel :public OBoundControlModel
,public OPropertyChangeListener
- ,public ::utl::OAggregationArrayUsageHelper< ORadioButtonModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< ORadioButtonModel >
{
::rtl::OUString m_sReferenceValue; // Referenzwert zum Checken des Buttons
sal_Int16 m_nDefaultChecked; // Soll beim Reset gecheckt werden ?
diff --git a/forms/source/component/Time.cxx b/forms/source/component/Time.cxx
index 83e3c173cae4..53c2461f60f3 100644
--- a/forms/source/component/Time.cxx
+++ b/forms/source/component/Time.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Time.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -69,17 +69,19 @@
#ifndef _TOOLS_TIME_HXX
#include <tools/time.hxx>
#endif
-#ifndef _UNOTOOLS_DATETIME_HXX_
-#include <unotools/datetime.hxx>
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
#endif
-#ifndef _UTL_DB_CONVERSION_HXX_
-#include <unotools/dbconversion.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
#ifndef _COM_SUN_STAR_SDBC_DATATYPE_HPP_
#include <com/sun/star/sdbc/DataType.hpp>
#endif
+using namespace dbtools;
+
//.........................................................................
namespace frm
{
@@ -238,8 +240,7 @@ sal_Bool OTimeModel::_commit()
{
sal_Int32 nAsInt(0);
aNewValue >>= nAsInt;
- Time aToolsValue(nAsInt);
- typeConvert(aToolsValue, aTime);
+ aTime = DBTypeConversion::toTime(nAsInt);
}
if (!m_bDateTimeField)
@@ -292,7 +293,7 @@ void OTimeModel::_reset()
else
{ // aktuelles Datum einstellen
Time aCurrentTime;
- aValue <<= DBTypeConversion::toINT32(aCurrentTime);
+ aValue <<= (sal_Int32)aCurrentTime.GetTime();
}
{ // release our mutex once (it's acquired in the calling method !), as setting aggregate properties
diff --git a/forms/source/component/Time.hxx b/forms/source/component/Time.hxx
index eca2c0cec526..d819d93cb433 100644
--- a/forms/source/component/Time.hxx
+++ b/forms/source/component/Time.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Time.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:52:16 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -76,7 +76,7 @@ namespace frm
//==================================================================
class OTimeModel
:public OEditBaseModel
- ,public ::utl::OAggregationArrayUsageHelper< OTimeModel >
+ ,public ::comphelper::OAggregationArrayUsageHelper< OTimeModel >
{
staruno::Any m_aSaveValue;
sal_Bool m_bDateTimeField;
diff --git a/forms/source/inc/InterfaceContainer.hxx b/forms/source/inc/InterfaceContainer.hxx
index 8094c2247e6a..c16ac228f294 100644
--- a/forms/source/inc/InterfaceContainer.hxx
+++ b/forms/source/inc/InterfaceContainer.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: InterfaceContainer.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:50:25 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -62,14 +62,14 @@
#ifndef _FRM_INTERFACE_CONTAINER_HXX_
#define _FRM_INTERFACE_CONTAINER_HXX_
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-#ifndef _UTL_TYPES_HXX_
-#include <unotools/types.hxx>
+#ifndef _COMPHELPER_TYPES_HXX_
+#include <comphelper/types.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
#ifndef _COM_SUN_STAR_CONTAINER_XNAMEREPLACE_HPP_
@@ -135,7 +135,7 @@
#include <cppuhelper/component.hxx>
#endif
-using namespace utl;
+using namespace comphelper;
//.........................................................................
namespace frm
@@ -151,7 +151,7 @@ namespace frm
typedef ::std::vector<InterfaceRef> OInterfaceArray;
-typedef ::std::hash_multimap< ::rtl::OUString, InterfaceRef, ::utl::UStringHash, ::utl::UStringEqual> OInterfaceMap;
+typedef ::std::hash_multimap< ::rtl::OUString, InterfaceRef, ::comphelper::UStringHash, ::comphelper::UStringEqual> OInterfaceMap;
//==================================================================
// FmForms
@@ -279,7 +279,7 @@ class OFormComponents : public FormComponentsBase,
{
protected:
::osl::Mutex m_aMutex;
- ::utl::InterfaceRef m_xParent;
+ ::comphelper::InterfaceRef m_xParent;
public:
OFormComponents(const staruno::Reference<starlang::XMultiServiceFactory>& _rxFactory);
@@ -294,8 +294,8 @@ public:
virtual void SAL_CALL disposing();
// starform::XFormComponent
- virtual ::utl::InterfaceRef SAL_CALL getParent() throw(staruno::RuntimeException);
- virtual void SAL_CALL setParent(const ::utl::InterfaceRef& Parent) throw(starlang::NoSupportException, staruno::RuntimeException);
+ virtual ::comphelper::InterfaceRef SAL_CALL getParent() throw(staruno::RuntimeException);
+ virtual void SAL_CALL setParent(const ::comphelper::InterfaceRef& Parent) throw(starlang::NoSupportException, staruno::RuntimeException);
};
//.........................................................................
} // namespace frm
diff --git a/forms/source/misc/InterfaceContainer.cxx b/forms/source/misc/InterfaceContainer.cxx
index 9fcbb65c9efe..4f6e4118f23b 100644
--- a/forms/source/misc/InterfaceContainer.cxx
+++ b/forms/source/misc/InterfaceContainer.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: InterfaceContainer.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:50:48 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -66,23 +66,23 @@
#ifndef _CPPUHELPER_QUERYINTERFACE_HXX_
#include <cppuhelper/queryinterface.hxx>
#endif
-#ifndef _UNOTOOLS_EVENTATTACHERMGR_HXX_
-#include <unotools/eventattachermgr.hxx>
+#ifndef _COMPHELPER_EVENTATTACHERMGR_HXX_
+#include <comphelper/eventattachermgr.hxx>
#endif
-#ifndef _UTL_TYPES_HXX_
-#include <unotools/types.hxx>
+#ifndef _COMPHELPER_TYPES_HXX_
+#include <comphelper/types.hxx>
#endif
-#ifndef _UNOTOOLS_ENUMHELPER_HXX_
-#include <unotools/enumhelper.hxx>
+#ifndef _COMPHELPER_ENUMHELPER_HXX_
+#include <comphelper/enumhelper.hxx>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include <unotools/container.hxx>
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
#endif
-#ifndef _UTL_SEQUENCE_HXX_
-#include <unotools/sequence.hxx>
+#ifndef _COMPHELPER_SEQUENCE_HXX_
+#include <comphelper/sequence.hxx>
#endif
#ifndef _FRM_PROPERTY_HRC_
@@ -130,7 +130,7 @@ OInterfaceContainer::OInterfaceContainer(
,m_aElementType(_rElementType)
,m_xServiceFactory(_rxFactory)
{
- m_xEventAttacher = ::utl::createEventAttacherManager(m_xServiceFactory);
+ m_xEventAttacher = ::comphelper::createEventAttacherManager(m_xServiceFactory);
}
//------------------------------------------------------------------------------
@@ -256,7 +256,7 @@ void SAL_CALL OInterfaceContainer::readEvents(const staruno::Reference<stario::X
else
{
// neuen EventManager
- m_xEventAttacher = ::utl::createEventAttacherManager(m_xServiceFactory);
+ m_xEventAttacher = ::comphelper::createEventAttacherManager(m_xServiceFactory);
}
}
@@ -408,12 +408,12 @@ void OInterfaceContainer::propertyChange(const starbeans::PropertyChangeEvent& e
{
::osl::MutexGuard aGuard( m_rMutex );
OInterfaceMap::iterator i = find(m_aMap.begin(), m_aMap.end(),
- pair<const ::rtl::OUString, InterfaceRef >(::utl::getString(evt.OldValue),evt.Source));
+ pair<const ::rtl::OUString, InterfaceRef >(::comphelper::getString(evt.OldValue),evt.Source));
if (i != m_aMap.end())
{
InterfaceRef xCorrectType((*i).second);
m_aMap.erase(i);
- m_aMap.insert(pair<const ::rtl::OUString, InterfaceRef >(::utl::getString(evt.NewValue),xCorrectType));
+ m_aMap.insert(pair<const ::rtl::OUString, InterfaceRef >(::comphelper::getString(evt.NewValue),xCorrectType));
}
}
}
@@ -436,7 +436,7 @@ staruno::Type SAL_CALL OInterfaceContainer::getElementType() throw(staruno::Runt
staruno::Reference<starcontainer::XEnumeration> SAL_CALL OInterfaceContainer::createEnumeration() throw( staruno::RuntimeException )
{
::osl::MutexGuard aGuard( m_rMutex );
- return new ::utl::OEnumerationByIndex(static_cast<starcontainer::XIndexAccess*>(this));
+ return new ::comphelper::OEnumerationByIndex(static_cast<starcontainer::XIndexAccess*>(this));
}
// starcontainer::XNameAccess
@@ -847,7 +847,7 @@ staruno::Sequence<staruno::Type> SAL_CALL OFormComponents::getTypes() throw(star
staruno::Sequence<staruno::Type> aOwnTypes(1);
aOwnTypes.getArray()[0] = ::getCppuType(static_cast<staruno::Reference<starform::XFormComponent>*>(NULL));
- return ::utl::concatSequences(aBaseTypes, aComponentTypes, aOwnTypes);
+ return ::comphelper::concatSequences(aBaseTypes, aComponentTypes, aOwnTypes);
}
//------------------------------------------------------------------------------
diff --git a/forms/source/inc/property.hxx b/forms/source/inc/property.hxx
index 8e6871fa4e41..ef5e2129cb07 100644
--- a/forms/source/inc/property.hxx
+++ b/forms/source/inc/property.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: property.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 16:29:06 $
+ * last change: $Author: fs $ $Date: 2000-10-19 11:50:25 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -79,17 +79,17 @@
#include <cppuhelper/proptypehlp.hxx>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UNOTOOLS_PROPERTY_AGGREGATION_HXX_
-#include <unotools/propagg.hxx>
+#ifndef _COMPHELPER_PROPERTY_AGGREGATION_HXX_
+#include <comphelper/propagg.hxx>
#endif
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-using namespace utl;
+using namespace comphelper;
//=========================================================================
//= property helper classes
@@ -153,8 +153,8 @@ private:
};
//..................................................................
-// a class implementing the utl::IPropertyInfoService
-class ConcretInfoService : public ::utl::IPropertyInfoService
+// a class implementing the comphelper::IPropertyInfoService
+class ConcretInfoService : public ::comphelper::IPropertyInfoService
{
public:
virtual sal_Int32 getPreferedPropertyId(const ::rtl::OUString& _rName);